===========
manila.conf
===========

The ``manila.conf`` file is installed in ``/etc/manila`` by default.
When you manually install the Shared File Systems service, the options
in the ``manila.conf`` file are set to default values.

The ``manila.conf`` file contains most of the options needed to configure
the Shared File Systems service.

.. only:: html

   .. literalinclude:: ../../../_static/manila.conf.sample
      :language: ini

.. only:: latex

   See the online version of this documentation for the full config
   file example.
